@@ -1,25 +1,32 @@
-"""Library to ease the implementation of the repository pattern in Python projects.."""
+"""Library to ease the implementation of the repository pattern in Python projects."""
 
 from .adapters import (
-    AbstractRepository,
     FakeRepository,
     FakeRepositoryDB,
+    Models,
+    OptionalModelOrModels,
+    OptionalModels,
     PypikaRepository,
     Repository,
     TinyDBRepository,
 )
-from .exceptions import EntityNotFoundError
-from .model import Entity
+from .exceptions import AutoIncrementError, EntityNotFoundError
+from .model import Entity, EntityID
 from .services import load_repository
 
 __all__ = [
-    "AbstractRepository",
+    "AutoIncrementError",
     "Entity",
+    "EntityID",
     "EntityNotFoundError",
     "FakeRepository",
     "FakeRepositoryDB",
+    "Models",
+    "OptionalModels",
+    "OptionalModelOrModels",
     "PypikaRepository",
-    "TinyDBRepository",
     "Repository",
+    "Repository",
+    "TinyDBRepository",
     "load_repository",
 ]
